Struct fuel_core_sync::import::Config
source · pub struct Config {
pub block_stream_buffer_size: usize,
pub header_batch_size: usize,
}Expand description
Parameters for the import task.
Fields
block_stream_buffer_size: usizeThe maximum number of get transaction requests to make in a single batch.
header_batch_size: usizeThe maximum number of headers to request in a single batch.