Struct fuel_core_sync::state::State

source ·
pub struct State { /* private fields */ }
State of the sync service.

The state takes evidence and produces a status.

Implementations

source

impl State

source

pub fn new( committed: impl Into<Option<u32>>, observed: impl Into<Option<u32>> ) -> Self

Create a new state from the current committed and observed heights.

source

pub fn process_range(&self) -> Option<RangeInclusive<u32>>

Get the current range to process.

source

pub fn commit(&mut self, height: u32)

Record that a block has been committed.

source

pub fn observe(&mut self, height: u32) -> bool

Record that a block has been observed.

source

pub fn failed_to_process(&mut self, range: RangeInclusive<u32>)

Record that a range of blocks have failed to process.