Struct fuel_core_sync::import::Config
source · pub struct Config {
pub max_get_header_requests: usize,
pub max_get_txns_requests: usize,
}Expand description
Parameters for the import task.
Fields
max_get_header_requests: usizeThe maximum number of get header requests to make in a single batch.
max_get_txns_requests: usizeThe maximum number of get transaction requests to make in a single batch.